==> dif-presentation-core-2.1.7-20150513.172652-1-sources.jar: pt/digitalis/dif/presentation/ioc/ControllerModule.java <==
/**
 * - Digitalis Internal Framework v2.0 -
 *
 * (C) 2007, Digitalis Informatica.
 *
 * Distribuicao e Gestao de Informatica, Lda.
 * Estrada de Paco de Arcos num.9 - Piso -1
 * 2780-666 Paco de Arcos
 * Telefone: (351) 21 4408990
 * Fax: (351) 21 4408999
 * http://www.digitalis.pt
 */
package pt.digitalis.dif.presentation.ioc;

import pt.digitalis.dif.controller.http.ChALHTTPImpl;
import pt.digitalis.dif.controller.http.DispatcherErrorHandlerHTTPImpl;
import pt.digitalis.dif.controller.http.DispatcherHTTPImpl;
import pt.digitalis.dif.controller.interfaces.IChAL;
import pt.digitalis.dif.controller.interfaces.IDIFDispatcher;
import pt.digitalis.dif.controller.interfaces.IDispatcherErrorHandler;
import pt.digitalis.utils.ioc.modules.IIoCModule;
import pt.digitalis.utils.ioc.modules.IoCBinder;

/**
 * Contribution for parameter validation. Default constraints and validators
 *
 * @author Pedro Viegas <a href="mailto:pviegas@digitalis.pt">pviegas@digitalis.pt</a>
 * @author Rodrigo Gonalves <a href="mailto:rgoncalves@digitalis.pt">rgoncalves@digitalis.pt</a>
 * @created Nov 16, 2007
 *
 */
public class ControllerModule implements IIoCModule {

    /**
     * @see pt.digitalis.utils.ioc.modules.IIoCModule#configure(pt.digitalis.utils.ioc.modules.IoCBinder)
     */
    public void configure(IoCBinder binder) {

        // ChALs and Dispatchers
        binder.bind(IChAL.class, ChALHTTPImpl.class).withId("http").asSingleton();
        binder.bind(IDIFDispatcher.class, DispatcherHTTPImpl.class).withId("http");
        binder.bind(IDispatcherErrorHandler.class,  DispatcherErrorHandlerHTTPImpl.class).withId("http").asSingleton();
    }
}

==> dif-presentation-core-2.2.2-sources.jar: pt/digitalis/dif/presentation/ioc/ControllerModule.java <==
/**
 * - Digitalis Internal Framework v2.0 - (C) 2007, Digitalis Informatica. Distribuicao e Gestao de Informatica, Lda.
 * Estrada de Paco de Arcos num.9 - Piso -1 2780-666 Paco de Arcos Telefone: (351) 21 4408990 Fax: (351) 21 4408999
 * http://www.digitalis.pt
 */
package pt.digitalis.dif.presentation.ioc;

import pt.digitalis.dif.controller.http.ChALHTTPImpl;
import pt.digitalis.dif.controller.http.DIFPresentationAPI;
import pt.digitalis.dif.controller.http.DispatcherErrorHandlerHTTPImpl;
import pt.digitalis.dif.controller.http.DispatcherHTTPImpl;
import pt.digitalis.dif.controller.interfaces.IChAL;
import pt.digitalis.dif.controller.interfaces.IDIFDispatcher;
import pt.digitalis.dif.controller.interfaces.IDispatcherErrorHandler;
import pt.digitalis.dif.dem.interfaces.IDIFAPI;
import pt.digitalis.utils.ioc.modules.IIoCModule;
import pt.digitalis.utils.ioc.modules.IoCBinder;

/**
 * Contribution for parameter validation. Default constraints and validators
 * 
 * @author Pedro Viegas <a href="mailto:pviegas@digitalis.pt">pviegas@digitalis.pt</a>
 * @author Rodrigo Gonalves <a href="mailto:rgoncalves@digitalis.pt">rgoncalves@digitalis.pt</a>
 * @created Nov 16, 2007
 */
public class ControllerModule implements IIoCModule {

    /**
     * @see pt.digitalis.utils.ioc.modules.IIoCModule#configure(pt.digitalis.utils.ioc.modules.IoCBinder)
     */
    public void configure(IoCBinder binder)
    {

        // ChALs and Dispatchers
        binder.bind(IChAL.class, ChALHTTPImpl.class).withId("http").asSingleton();
        binder.bind(IDIFDispatcher.class, DispatcherHTTPImpl.class).withId("http");
        binder.bind(IDispatcherErrorHandler.class, DispatcherErrorHandlerHTTPImpl.class).withId("http").asSingleton();

        // API
        binder.bind(IDIFAPI.class, DIFPresentationAPI.class).withId(DIFPresentationAPI.class.getSimpleName());
    }
}
